useDynLib(directlabels, .registration=TRUE)
exportPattern("^[[:alpha:]]+")
S3method("direct.label", "trellis")
S3method("direct.label", "ggplot")
import(grid)
S3method("drawDetails", "dlgrob")
importFrom("grDevices", "col2rgb")
importFrom("grDevices", "dev.off", "png")
importFrom("stats", "approx", "update", "var")
importFrom("utils", "capture.output", "data")
importFrom("Rcpp", "evalCpp")
importFrom("data.table", "fcase")
