\name{in1box}
\alias{in1box}
\title{in1box}
\description{Calculate how many points fall in a \code{box}.}
\usage{in1box(p, box)}
\arguments{
  \item{p}{p }
  \item{box}{box }
}



\author{Toby Dylan Hocking <toby.hocking@r-project.org> [aut, cre] (ORCID: <https://orcid.org/0000-0002-3146-0865>)}





