\name{midrange}
\alias{midrange}
\title{midrange}
\description{Point halfway between the min and max}
\usage{midrange(x)}
\arguments{
  \item{x}{x }
}



\author{Toby Dylan Hocking <toby.hocking@r-project.org> [aut, cre] (ORCID: <https://orcid.org/0000-0002-3146-0865>)}





