\name{angled.boxes}
\alias{angled.boxes}
\docType{data}
\title{angled boxes}
\description{Draw a box with the label \code{\link{inside}}, at the point furthest away from
the plot border and any other curve.}
\usage{"angled.boxes"}





