\name{dl.env}
\alias{dl.env}
\docType{data}
\title{dl env}
\description{This environment holds an integer id that will be incremented to
get a unique id for each \code{\link{dlgrob}}.}
\usage{"dl.env"}





