\name{maxvar.qp}
\alias{maxvar.qp}
\docType{data}
\title{maxvar qp}
\description{Label first or last points, whichever are more spread out, and use
a QP solver to make sure the labels do not collide.}
\usage{"maxvar.qp"}





